@@ -7,23 +7,26 @@ use v5.10;
 use Getopt::Compact;
 use Data::Dumper;
 use File::Slurp;
-use Test::Legal::Util qw/ check_license_files  write_LICENSE license_types /; 
+use Test::Legal::Util qw/ load_meta check_license_files  write_LICENSE license_types /; 
 use Log::Log4perl ':easy';
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use constant { 
 	LOG_PARAM  => { File=>'STDOUT', level=>$INFO, layout=>'%m%n', category=>'main'},
 	LOG_MOD    => [('main', 'Test::Legal', 'Test::Legal::Util')],
 };
 
+
 our   $o;
 our  $opts;
 BEGIN {
+#@ARGV = qw{ ../t/dat/bak -d check };
+
 Log::Log4perl->easy_init( LOG_PARAM() , { %{LOG_PARAM()}, category=>'Test::Legal'} );
 
 $o = new Getopt::Compact 
-    modes  => [qw( yes )],
-	args   => 'dir  [check|add|remove|t|list]',
+    modes  => [qw( yes licenses)],
+	args   => 'dir  [check | add | remove | t]',
 	struct => [ 
             [[qw(t type)], 'license type'],
             [[qw(a author)], 'copyright holder'],
@@ -33,15 +36,22 @@ $o = new Getopt::Compact
 }
 $opts = $o->opts;
 
-
 use constant {  BASE   => shift || '.' ,
 			    ACTION => shift||'check',
 };
+
+## Option Processing
+$opts->{licenses} and INFO join "\t", license_types and exit;
+## Error Checking
+load_meta BASE or ERROR qq(no META file found in dir ").BASE.qq(". Aborting...) and exit;
+
+eval q(
 use Test::Legal  qw/ disable_test_builder /,
                  license_ok=>{ base=>BASE ,
 					           #actions => [qw/ fix /] ,
                  } ,
 ;
+1;
 
 DEBUG 'Scanning '. BASE ;
 given (ACTION) {
@@ -52,9 +62,6 @@ given (ACTION) {
 						unlink BASE.'/LICENSE'  or warn "$!\n" and exit 1;
 						DEBUG "unkinked" ;
 	                  }
-	when (/^list$/i)  { disable_test_builder;
-			            INFO join "\t", license_types
-                      }
 	when (/^check$/i) { disable_test_builder;
 			            check_license_files( BASE );
                       }
@@ -63,3 +70,4 @@ given (ACTION) {
 	default:            INFO	 $o->usage and exit; 
 }
 
+) or say $@;
